@@ -1,3 +1,5 @@
+# vim: tabstop=4 shiftwidth=4 softtabstop=4
+
 # Copyright 2012 United States Government as represented by the
 # Administrator of the National Aeronautics and Space Administration.
 # All Rights Reserved.
@@ -24,7 +26,6 @@ from horizon import forms
 from horizon import messages
 
 from openstack_dashboard import api
-from openstack_dashboard.usage import quotas
 
 
 class FloatingIpAllocate(forms.SelfHandlingForm):
@@ -37,19 +38,11 @@ class FloatingIpAllocate(forms.SelfHandlingForm):
 
     def handle(self, request, data):
         try:
-            # Prevent allocating more IP than the quota allows
-            usages = quotas.tenant_quota_usages(request)
-            if usages['floating_ips']['available'] <= 0:
-                error_message = _('You are already using all of your available'
-                                  ' floating IPs.')
-                self.api_error(error_message)
-                return False
-
             fip = api.network.tenant_floating_ip_allocate(request,
-                                                          pool=data['pool'])
+                                                       pool=data['pool'])
             messages.success(request,
                              _('Allocated Floating IP %(ip)s.')
                              % {"ip": fip.ip})
             return fip
-        except Exception:
+        except:
             exceptions.handle(request, _('Unable to allocate Floating IP.'))
